@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import division # 1/2 == .5 (par defaut, 1/2 == 0)
-from __future__ import with_statement
 
 ##--------------------------------------#######
 #                  Feuille                    #
@@ -29,9 +27,9 @@ from __future__ import with_statement
 
 from keyword import kwlist
 from random import choice
-from string import letters
+from string import ascii_letters
 from math import pi as PI, e as E
-from types import MethodType, GeneratorType, TypeType
+from types import MethodType, GeneratorType
 from operator import attrgetter
 import re
 import time
@@ -40,7 +38,7 @@ from numpy import array
 
 from sympy import Symbol, Wild, sympify, oo
 
-from ..pylib import uu, is_in, str3, property2, print_error, rstrip_, CompressedList
+from ..pylib import is_in, property2, print_error, rstrip_, CompressedList
 from ..mathlib.intervalles import Union, Intervalle
 from ..mathlib.parsers import VAR, NBR_SIGNE, traduire_formule, \
                         _convertir_separateur_decimal
@@ -56,7 +54,7 @@ from .textes import Texte, Texte_generique
 ##from .labels import Label_generique
 from .vecteurs import Vecteur_libre
 from .variables import Variable, XMinVar, XMaxVar, YMinVar, YMaxVar, Dpx, Dpy, \
-                       Variable_affichage, Pixel_unite
+                       Variable_affichage, Variable_generique, Pixel_unite
 
 from .pseudo_canvas import _pseudocanvas
 from .. import param
@@ -67,7 +65,7 @@ PatternType = type(re.compile(''))
 
 
 def is_equation(chaine):
-    u"""Teste si une chaîne correspond bien à une équation."""
+    """Teste si une chaîne correspond bien à une équation."""
     if chaine.count('=') != 1:
         return False
     left, right = chaine.split('=')
@@ -87,7 +85,7 @@ def is_equation(chaine):
 #assert geo.Objet is Objet
 
 def parse_equation(chaine):
-    u"""Associe à une équation l'objet géométrique correspondant.
+    """Associe à une équation l'objet géométrique correspondant.
 
     Vérifie que la chaîne est une équation, et retourne une chaîne
     correspondant à l'objet géométrique correspondant le cas échéant.
@@ -101,7 +99,7 @@ def parse_equation(chaine):
 
     left, right = chaine.split('=')
     chaine = left + '-(' + right + ')'
-    chaine = traduire_formule(chaine, fonctions=mathlib.universal_functions.__dict__.keys())
+    chaine = traduire_formule(chaine, fonctions=list(mathlib.universal_functions.__dict__.keys()))
     try:
         expr = sympify(chaine).expand()
     except Exception:
@@ -174,11 +172,11 @@ class Liste_objets(object):
     def __str__(self):
         return self.classe.__name__.split("_")[0] + 's: ' + ', '.join(obj.nom for obj in self)
 
-    __unicode__ = __repr__ = __str__
+    __repr__ = __str__
 
 
 class ModeTolerant(object):
-    u'''Mode d'exécution tolérant aux erreurs.
+    '''Mode d'exécution tolérant aux erreurs.
     Cela sert essentiellement à charger un fichier d'une ancienne version de WxGéométrie.'''
     def __init__(self, feuille, mode = True):
         self.feuille = feuille
@@ -193,7 +191,7 @@ class ModeTolerant(object):
 
 
 class Dictionnaire_objets(dict):
-    u"""Cette classe est un conteneur pour les objets de la feuille, qui sont tous ses attributs,
+    """Cette classe est un conteneur pour les objets de la feuille, qui sont tous ses attributs,
     sauf ceux précédés de __ (attributs reserves pour tous les objets de la classe).
     Elle contient aussi tous les objets geometriques.
     Certaines methodes standard (comme __setattr__) sont aussi interceptées ou redefinies.
@@ -214,8 +212,7 @@ class Dictionnaire_objets(dict):
     les inscrire dans `_noms_interdits`.
     """
 
-    __slots__ = ('feuille', '__timestamp', '__renommer_au_besoin', '__tmp_dict',
-                 '_noms_restreints', '_noms_interdits', '_suppression_impossible')
+    __slots__ = ('feuille', '__timestamp', '__renommer_au_besoin', '__tmp_dict')
 
     _noms_restreints = {re.compile('f[0-9]+(_prime)*$'): Fonction, 'xmin': XMinVar,
                       'xmax': XMaxVar, 'ymin': YMinVar, 'ymax': YMaxVar, 'dpx': Dpx,
@@ -241,7 +238,7 @@ class Dictionnaire_objets(dict):
 
 
     def clear(self):
-        u"""Réinitialise le dictionnaire des objets.
+        """Réinitialise le dictionnaire des objets.
 
         Ne pas utiliser directement, mais utiliser plutôt `Feuille.effacer()`
         qui rafraichit correctement l'affichage."""
@@ -253,20 +250,20 @@ class Dictionnaire_objets(dict):
         dict.update(self, **_tmp)
         # On ajoute au dictionnaire courant les objets géométriques, et uniquement eux
         # (pas toutes les classes de geolib !)
-        self.update((key, val) for key, val in G.__dict__.iteritems() \
+        self.update((key, val) for key, val in G.__dict__.items() \
                     if isinstance(val, type) and issubclass(val, Objet))
         # Les noms de classe peuvent aussi être tapés en minuscules (c'est plus rapide à taper)
-        self.update((key.lower(), val) for key, val in G.__dict__.iteritems() \
+        self.update((key.lower(), val) for key, val in G.__dict__.items() \
                     if isinstance(val, type) and issubclass(val, Objet))
 
         # On ajoute au dictionnaire les fonctions mathématiques courantes
-        self.update((key, val) for key, val in mathlib.universal_functions.__dict__.iteritems() \
+        self.update((key, val) for key, val in mathlib.universal_functions.__dict__.items() \
                     if key[0] != "_" and key != "division")
 
         self.update(pi = PI, e = E, oo = oo, \
                     Intervalle = Intervalle, Union = Union, \
                     x = Symbol("x"), y = Symbol("y"), z = Symbol("z"), \
-                    t = Symbol("t"), range=range, xrange=xrange)
+                    t = Symbol("t"), range=range)
 
         self.update(pause = self.feuille.pause, erreur = self.feuille.erreur,
                     effacer = self.feuille.effacer,
@@ -290,7 +287,7 @@ class Dictionnaire_objets(dict):
 
 
     def add(self, valeur, nom_suggere=''):
-        u"""Ajoute l'objet `valeur` à la feuille.
+        """Ajoute l'objet `valeur` à la feuille.
 
         Si `nom_suggere` est donné, et que le nom suggéré n'est pas déjà
         utilisé, l'objet est référencé sous ce nom.
@@ -302,7 +299,7 @@ class Dictionnaire_objets(dict):
 
 
     def _dereferencer(self, objet):
-        u"Commande de bas niveau. Ne pas utiliser directement !"
+        "Commande de bas niveau. Ne pas utiliser directement !"
         if objet._nom:
             self.pop(objet._nom)
             # Important: pour que l'objet soit bien considéré non référencé
@@ -311,7 +308,7 @@ class Dictionnaire_objets(dict):
 
 
     def __setitem__(self, nom, valeur):
-        u"""Crée un objet de la feuille nommé `nom`, et ayant pour valeur `valeur`.
+        """Crée un objet de la feuille nommé `nom`, et ayant pour valeur `valeur`.
 
         Remarque: les syntaxes `objets['a'] = 3` et `objets.a = 3` sont équivalentes.
 
@@ -349,13 +346,15 @@ class Dictionnaire_objets(dict):
         # Bien sûr, il faut en particulier que la valeur soit un objet de meme type.
         # (A = Variable(3) n'est pas valide si A est un point !)
 
-        if self.has_key(nom):
+        if nom in self:
             try:
                 # Ne PAS rattacher la feuille à l'objet tant qu'il n'est pas enregistré
                 # sur la feuille. En particulier, pour un polygone, rattacher la feuille
                 # provoque déjà l'enregistrement des sommets sur la feuille, alors que rien
                 # ne garantisse que le polygone lui-même soit enregistré avec succès.
-                self[nom]._update(valeur)
+                # Le paramètre `raw=True` indique que pour une variable, il faut retourner
+                # l'objet `Variable` lui-même, et non sa valeur comme habituellement.
+                self.__getitem(nom, raw=True)._update(valeur)
                 # On quitte, car le nom fait toujours référence au même objet, qui est
                 # déjà enregistré sur la feuille.
                 return
@@ -368,7 +367,7 @@ class Dictionnaire_objets(dict):
                         print("Warning: '%s' renommé en '%s'." %(nom, new))
                     nom = self.__tmp_dict[nom] = new
                 else:
-                    self.erreur(u"Ce nom est d\xe9ja utilis\xe9 : " + nom, NameError)
+                    self.erreur("Ce nom est déjà utilisé : " + nom, NameError)
 
 
         if not isinstance(valeur, Objet):
@@ -382,12 +381,12 @@ class Dictionnaire_objets(dict):
                 return
 
             # 'A = Point' est un alias de 'A = Point()'
-            elif isinstance(valeur, TypeType) and issubclass(valeur, Objet):
+            elif isinstance(valeur, type) and issubclass(valeur, Objet):
                 valeur = valeur()
 
             # Par convénience, certains types sont automatiquement convertis :
             # - Variable
-            elif isinstance(valeur, (int, long, float, str, unicode)): # u=3 cree une variable
+            elif isinstance(valeur, (int, float, str)): # u=3 cree une variable
                 valeur = Variable(valeur)
 
             # - Point
@@ -397,7 +396,7 @@ class Dictionnaire_objets(dict):
             elif hasattr(valeur, "__iter__"):
                 valeur = tuple(valeur)
                 # - Texte
-                if len(valeur) in (1, 3) and isinstance(tuple(valeur)[0], basestring):
+                if len(valeur) in (1, 3) and isinstance(tuple(valeur)[0], str):
                     # t=["Bonjour!"] cree un texte
                     # t=('Bonjour!', 2, 3) également
                     valeur = Texte(*valeur)
@@ -457,8 +456,12 @@ class Dictionnaire_objets(dict):
 
 
 
-    def __getitem(self, nom):
-        u"""Usage interne: code commun aux méthodes `.__getitem__()` et `.get()`."""
+    def __getitem(self, nom, raw=False):
+        """Usage interne: code commun aux méthodes `.__getitem__()` et `.get()`.
+
+        Le paramètre `raw=True` permet de récupérer les variables elles-mêmes
+        (et non leur contenu).
+        """
         # renommage temporaire :
         nom = self.__tmp_dict.get(nom, nom)
         # (utilisé en cas de chargement d'un fichier ancien lors d'un conflit de nom).
@@ -470,19 +473,25 @@ class Dictionnaire_objets(dict):
             return self.noms
         elif nom == "_":
             return self.__derniere_valeur()
-        return dict.__getitem__(self, self.__convertir_nom(nom))
+        value = dict.__getitem__(self, self.__convertir_nom(nom))
+        if isinstance(value, Variable_generique) and not raw:
+            return value.val
+        return value
 
+    def get_raw_item(self, nom):
+        "Permet de récupérer les variables elles-mêmes (et non leur contenu)."
+        return self.__getitem(nom, raw=True)
 
     def __getitem__(self, nom):
         try:
             return self.__getitem(nom)
         except KeyError:
-            if nom == 'bogu5_123_aTTri8ute' and contexte['afficher_messages']:
-                # PyShell détecté, désactivation des messages d'erreur...
-                contexte['afficher_messages'] = False
-            else:
-                assert 'erreur' in self
-                self.erreur(u"Objet introuvable sur la feuille : " + nom, KeyError)
+            if nom in ('_ipython_canary_method_should_not_exist_',
+                       'bogu5_123_aTTri8ute', '__dict__'):
+                # Tests effectués par PyShell ou Ipython, ne pas afficher de message.
+                raise
+            assert 'erreur' in self
+            self.erreur("Objet introuvable sur la feuille : " + nom, KeyError)
 
     def get(self, nom, defaut=None):
         try:
@@ -517,7 +526,7 @@ class Dictionnaire_objets(dict):
 
 
     def lister(self, objets_caches=True, etiquettes=False, **kw):
-        u"""Retourne la liste des objets géométriques.
+        """Retourne la liste des objets géométriques.
 
         Le paramètre `objets_caches` indique s'il faut inclure les objets cachés.
 
@@ -554,7 +563,7 @@ class Dictionnaire_objets(dict):
 
 
     def supprimer(self, *objets):
-        u"""Supprime plusieurs objets dans le bon ordre.
+        """Supprime plusieurs objets dans le bon ordre.
 
         Supprime successivement plusieurs objets après les avoir classé
         hiérarchiquement. Cela évite d'avoir des erreurs avec certains
@@ -577,7 +586,7 @@ class Dictionnaire_objets(dict):
 
     @staticmethod
     def __convertir_nom(nom):
-        u'''Convertit les noms contenant des `, ', ou " en noms python corrects.'''
+        '''Convertit les noms contenant des `, ', ou " en noms python corrects.'''
         return nom.replace('`', '_prime').replace('"', '_prime_prime').replace("'", "_prime")
 
 
@@ -588,14 +597,14 @@ class Dictionnaire_objets(dict):
             return nom == pattern
 
     def __verifier_syntaxe_nom(self, objet, nom, **kw):
-        u"Vérifie que le nom est correct (ie. bien formé) et le modifie le cas échéant."
+        "Vérifie que le nom est correct (ie. bien formé) et le modifie le cas échéant."
 
         def err(msg):
             if kw.get('skip_err'):
                 return
             if self.__renommer_au_besoin:
                 new = self.feuille.nom_aleatoire(objet)
-                print(u"Warning: '%s' renommé en '%s'." %(nom, new))
+                print("Warning: '%s' renommé en '%s'." %(nom, new))
                 return new
             else:
                 self.erreur(msg, NameError)
@@ -606,43 +615,43 @@ class Dictionnaire_objets(dict):
 
         if nom in self.__class__.__dict__ \
                           or any(self.__match(pattern, nom) for pattern in self._noms_interdits):
-            return err(u"Nom r\xe9serv\xe9 : " + nom) # Pas d'accent dans le code ici a cause de Pyshell !
+            return err("Nom réservé : " + nom) # Pas d'accent dans le code ici a cause de Pyshell !
         # Les noms contenant '__' sont des noms réservés pour un usage futur éventuel (convention).
         if "__" in nom:
-            return err(u'Un nom ne peut pas contenir "__".')
+            return err('Un nom ne peut pas contenir "__".')
         if not re.match("""[A-Za-z_][A-Za-z0-9_'"`]*$""", nom):
-            return err(u"'%s' n'est pas un nom d'objet valide." %nom)
+            return err("'%s' n'est pas un nom d'objet valide." %nom)
 
         # Certains noms sont réservés à des usages spécifiques.
         # Par ex., les noms f1, f2... sont réservés aux fonctions (cf. module Traceur).
-        for pattern, types in self._noms_restreints.iteritems():
+        for pattern, types in self._noms_restreints.items():
             if self.__match(pattern, nom):
                 if isinstance(objet, types):
                     break
-                return err(u"Le nom %s est r\xe9serv\xe9 à certains types d'objets." %nom)
+                return err("Le nom %s est réservé à certains types d'objets." % nom)
 
         # Gestion des ' (qui servent pour les dérivées)
         if nom.endswith('_prime'):
             if isinstance(objet, Fonction):
-                return err(u'Nom interdit : %s est r\xe9serv\xe9 pour la d\xe9riv\xe9e.' %nom)
+                return err('Nom interdit : %s est réservé pour la dérivée.' % nom)
             else:
                 base = rstrip_(nom, '_prime')
                 if isinstance(self.get(base, None), Fonction):
-                    return err(u'Nom interdit : %s d\xe9signe d\xe9j\xe0 la d\xe9riv\xe9e de %s.' %(nom, base))
+                    return err('Nom interdit : %s désigne déjà la dérivée de %s.' % (nom, base))
         elif isinstance(objet, Fonction):
             # Si la fonction doit s'appeller f, on vérifie que f', f'', f''', etc. ne correspondent pas déjà à des objets.
             for existant in self:
                 if existant.startswith(nom) and rstrip_(existant, '_prime') == nom:
-                    return err(u'Ambiguit\xe9 : un objet %s existe d\xe9j\xe0.' %existant)
+                    return err('Ambiguité : un objet %s existe déjà.' % existant)
 
         return nom
 
 
     def _objet_renommable(self, objet, nom):
-        u"Vérifie que le nom peut-être attribué (c-à-d. qu'il est bien formé, et non utilisé)."
+        "Vérifie que le nom peut-être attribué (c-à-d. qu'il est bien formé, et non utilisé)."
         nom = self.__verifier_syntaxe_nom(objet, nom)
-        if self.has_key(nom):
-            self.erreur(u"Ce nom est déjà utilisé.", NameError)
+        if nom in self:
+            self.erreur("Ce nom est déjà utilisé.", NameError)
         return nom
 
 
@@ -655,7 +664,7 @@ class Dictionnaire_objets(dict):
                     + "': " + repr(self.noms)
 
     def __derniere_valeur(self):
-        u"Dernier objet créé."
+        "Dernier objet créé."
         return max(self.feuille.liste_objets(True), key = lambda obj:obj._timestamp)
 
 
@@ -664,7 +673,7 @@ class Dictionnaire_objets(dict):
 
 
 class Interprete_feuille(object):
-    u"""Exécute des commandes dans la feuille.
+    """Exécute des commandes dans la feuille.
 
     Reformule également les commandes avant de les exécuter."""
 
@@ -672,7 +681,7 @@ class Interprete_feuille(object):
         self.feuille = feuille
 
     def executer(self, commande, parser=True, signature=None):
-        u"""Exécute la commande dans la feuille.
+        """Exécute la commande dans la feuille.
 
         Si `parser=False`, les facilités de syntaxe (abréviations, etc.)
         sont désactivées pour plus de rapidité.
@@ -682,7 +691,7 @@ class Interprete_feuille(object):
         Voir aussi `commande_executee()`.
         """
         if commande.startswith('#'):
-            return u'Commentaire ignoré : %s' % commande
+            return 'Commentaire ignoré : %s' % commande
 
         if parser:
             commande = self.parser(commande)
@@ -698,9 +707,9 @@ class Interprete_feuille(object):
             val = eval(code, self.feuille.objets)
             if isinstance(val, Variable):
                 if val._type == "simple":
-                    retour = unicode(val.val)
+                    retour = str(val.val)
                 else:
-                    retour = '"' + val.contenu + '" : ' + unicode(val.val)
+                    retour = '"' + val.contenu + '" : ' + str(val.val)
             elif isinstance(val, (list, tuple, set)):
                 # Améliore la lisibilité de l'affichage pour une liste d'objets
                 # en affichant le nom des objets au lieu des objets eux-mêmes
@@ -726,17 +735,17 @@ class Interprete_feuille(object):
                 else:
                     retour += ')'
             else:
-                retour = unicode(val)
+                retour = str(val)
         except SyntaxError:
             exec(commande + '\n', self.feuille.objets)
             # Le + '\n' final contourne un bug de Python 2.5 avec with_statement
-            retour = u'Commande exécutée.'
+            retour = 'Commande exécutée.'
         finally:
             self.commande_executee(signature = signature)
         return retour
 
     def commande_executee(self, signature = None):
-        u"""Méthode appelée automatiquement après avoir exécuté une commande dans la feuille.
+        """Méthode appelée automatiquement après avoir exécuté une commande dans la feuille.
         Si l'on n'a pas utilisé la méthode executer(), il faut alors l'appeler manuellement."""
         self.feuille.historique.archiver(signature = signature)
         # TODO: A déplacer dans la console graphique d'exécution ?
@@ -750,7 +759,7 @@ class Interprete_feuille(object):
 
     @staticmethod
     def parser(commande):
-        u"""Convertit la commande en code Python.
+        """Convertit la commande en code Python.
 
         >>> from wxgeometrie.geolib.feuille import Interprete_feuille
         >>> Interprete_feuille.parser("[A B]")
@@ -832,7 +841,7 @@ class Interprete_feuille(object):
 
 
 class Historique_feuille(object):
-    u"""Historique de la feuille.
+    """Historique de la feuille.
 
     Permet d'enregistrer l'état de la feuille à un instant donné,
     et de le restaurer ensuite."""
@@ -850,7 +859,7 @@ class Historique_feuille(object):
 
 
     def archiver(self, signature=None):
-        u"""Sauvegarde l'état actuel de la feuille.
+        """Sauvegarde l'état actuel de la feuille.
 
         Notes concernant l'implémentation::
 
@@ -890,10 +899,10 @@ class Historique_feuille(object):
             if len(self.etats_annules) > self.n:
                 self.etats_annules.pop(0) # plus rapide que "self.etats_annules = self.etats_annules[-self.n:]"
             self.restaurer(self.etats[-1])
-            self.feuille.message(u"Action annulée.")
+            self.feuille.message("Action annulée.")
             self.feuille.modifiee = True
         else:
-            self.feuille.message(u"Impossible d'annuler.")
+            self.feuille.message("Impossible d'annuler.")
 
 
     def refaire(self):
@@ -903,10 +912,10 @@ class Historique_feuille(object):
             if len(self.etats) > self.n:
                 self.etats.pop(0) # plus rapide que "self.etats = self.etats[-self.n:]"
             self.restaurer(etat)
-            self.feuille.message(u"Action restaurée.")
+            self.feuille.message("Action restaurée.")
             self.feuille.modifiee = True
         else:
-            self.feuille.message(u"Impossible de restaurer.")
+            self.feuille.message("Impossible de restaurer.")
 
 
     def restaurer(self, txt):
@@ -923,7 +932,7 @@ class Historique_feuille(object):
 
 
 class Feuille(object):
-    u"""Feuille de travail.
+    """Feuille de travail.
 
     L'objet 'log' doit être une liste destinée à contenir tous les messages.
     """
@@ -1027,7 +1036,7 @@ class Feuille(object):
             self._actions.append(action)
 
     def affichage_perime(self):
-        u"""Indique que l'affichage doit être actualisé.
+        """Indique que l'affichage doit être actualisé.
 
         Très rapide (inutile d'optimiser les appels), car aucune actualisation
         n'a lieu, mais la feuille est juste marquée comme étant à actualiser."""
@@ -1053,7 +1062,7 @@ class Feuille(object):
             return self._infos[_key_]
 
     def _rafraichir_figures(self, tous_les_objets = False):
-        u"""Recrée les figures des objets sensibles à la fenêtre d'affichage.
+        """Recrée les figures des objets sensibles à la fenêtre d'affichage.
 
         Si tous_les_objets = True, les figure des objets non sensibles sont
         aussi récréées.
@@ -1134,12 +1143,12 @@ class Feuille(object):
         ymax = ymax if ymax is not None else self.fenetre[3]
         epsilon = 100*contexte['tolerance']
         if abs(xmax - xmin) < epsilon:
-            self.erreur((u"Le réglage de la fenêtre est incorrect (xmin=%s et xmax=%s sont trop proches).\n"
-                         u"(Les paramètres doivent être dans cet ordre: xmin, xmax, ymin, ymax.)")
+            self.erreur(("Le réglage de la fenêtre est incorrect (xmin=%s et xmax=%s sont trop proches).\n"
+                         "(Les paramètres doivent être dans cet ordre: xmin, xmax, ymin, ymax.)")
                         % (xmin, xmax), ValueError)
         elif abs(ymax - ymin) < epsilon:
-            self.erreur((u"Le réglage de la fenêtre est incorrect (ymin=%s et ymax=%s sont trop proches).\n"
-                         u"(Les paramètres doivent être dans cet ordre: xmin, xmax, ymin, ymax.)")
+            self.erreur(("Le réglage de la fenêtre est incorrect (ymin=%s et ymax=%s sont trop proches).\n"
+                         "(Les paramètres doivent être dans cet ordre: xmin, xmax, ymin, ymax.)")
                          % (ymin, ymax), ValueError)
         # Les 'float()' servent à contourner un bug de numpy 1.1.x et numpy 1.2.x (repr de float64)
         return float(min(xmin, xmax)), float(max(xmin, xmax)), float(min(ymin, ymax)), float(max(ymin, ymax))
@@ -1170,12 +1179,8 @@ class Feuille(object):
 
 
     def fenetre_modifiee(self):
-        self.objets.xmin.perime()
-        self.objets.xmax.perime()
-        self.objets.ymin.perime()
-        self.objets.ymax.perime()
-        self.objets.dpx.perime()
-        self.objets.dpy.perime()
+        for name in ('xmin', 'xmax', 'ymin', 'ymax', 'dpx', 'dpy'):
+            dict.__getitem__(self.objets, name).perime()
         # XXX: il ne devrait pas y avoir besoin d'appeler la méthode suivante :
         self._rafraichir_figures()
 
@@ -1184,7 +1189,7 @@ class Feuille(object):
 
 
     def liste_objets(self, objets_caches=None, tri=False, etiquettes=False):
-        u"""Liste des objets, triés éventuellement selon le style 'niveau'.
+        """Liste des objets, triés éventuellement selon le style 'niveau'.
 
         NB: un système de mise en cache est utilisé si possible, contrairement à .objets.lister().
         """
@@ -1217,14 +1222,14 @@ class Feuille(object):
 #########################################################################################
 
     def _dimensions_en_pixels(self):
-        u"Dimensions en pixels de la feuille affichée par le canevas."
+        "Dimensions en pixels de la feuille affichée par le canevas."
         if self.canvas is not _pseudocanvas:
             return self.canvas.dimensions
         else:
             return eval(self._infos['dimensions-pixels'])
 
     def fenetre_reellement_affichee(self):
-        u"""Fenêtre réellement affichée à l'écran.
+        """Fenêtre réellement affichée à l'écran.
 
         Dans le cas où le ratio abscisse/ordonnée est fixe (par exemple,
         si l'utilisateur impose un repère orthonormé), les valeurs
@@ -1267,7 +1272,7 @@ class Feuille(object):
 
 
     def coo2pix(self, x, y):
-        u"""Convertit des coordonnées en pixel."""
+        """Convertit des coordonnées en pixel."""
         if isinstance(x, (list, tuple)):
             x = array(x)
         if isinstance(y, (list, tuple)):
@@ -1279,7 +1284,7 @@ class Feuille(object):
         return px, py
 
     def pix2coo(self, px, py):
-        u"""Convertit un pixel en coordonnées."""
+        """Convertit un pixel en coordonnées."""
         if isinstance(px, (list, tuple)):
             px = array(px)
         if isinstance(py, (list, tuple)):
@@ -1292,7 +1297,7 @@ class Feuille(object):
         return x, y
 
     def dcoo2pix(self, dx, dy):
-        u"""Convertit un déplacement exprimé en coordonnées en un déplacement en pixels."""
+        """Convertit un déplacement exprimé en coordonnées en un déplacement en pixels."""
         l, h = self._dimensions_en_pixels()
         fenetre = self.fenetre_reellement_affichee()
         dpx = l*dx/(fenetre[1] - fenetre[0])
@@ -1300,7 +1305,7 @@ class Feuille(object):
         return dpx, dpy
 
     def dpix2coo(self, dpx, dpy):
-        u"""Convertit un déplacement exprimé en pixels en un déplacement exprimé en coordonnées."""
+        """Convertit un déplacement exprimé en pixels en un déplacement exprimé en coordonnées."""
         l, h = self._dimensions_en_pixels()
         fenetre = self.fenetre_reellement_affichee()
         dx = dpx*(fenetre[1] - fenetre[0])/l
@@ -1321,7 +1326,7 @@ class Feuille(object):
 
     @property
     def nom(self):
-        u"Destiné à être affiché."
+        "Destiné à être affiché."
         nom = self.infos("titre")
         if self.sauvegarde["nom"]:
            nom += ' - ' + self.sauvegarde["nom"]
@@ -1330,7 +1335,7 @@ class Feuille(object):
 
     @property
     def nom_complet(self):
-        u"Destiné à être affiché en haut de la fenêtre."
+        "Destiné à être affiché en haut de la fenêtre."
         nom = self.modifiee and "* " or ""
         liste = self.sauvegarde["nom"], self.infos("titre")
         nom += " - ".join(s for s in liste if s)
@@ -1354,7 +1359,7 @@ class Feuille(object):
 
 
     def sauvegarder(self, _as_list=False):
-        u"""Renvoie l'ensemble des commandes python qui permettra de recréer
+        """Renvoie l'ensemble des commandes python qui permettra de recréer
         la figure avec tous ses objets.
 
         La figure pourra ensuite être restaurée à l'aide la commande `charger()`.
@@ -1389,7 +1394,7 @@ class Feuille(object):
 
     def charger(self, commandes, rafraichir = True, archiver = True,
                                  mode_tolerant = False):
-        u"""Exécute un ensemble de commandes dans la feuille.
+        """Exécute un ensemble de commandes dans la feuille.
 
         Usage:
         f = Feuille()
@@ -1403,15 +1408,15 @@ class Feuille(object):
                 try:
                     exec(commandes, self.objets)
                 except:
-                    print "Liste des commandes:"
-                    print "--------------------"
-                    print commandes
-                    print "--------------------"
+                    print("Liste des commandes:")
+                    print("--------------------")
+                    print(commandes)
+                    print("--------------------")
                     try:
                         print_error()
                     except:
-                        print u"Affichage de l'erreur impossible !"
-                    self.erreur(u"Chargement incomplet de la feuille.")
+                        print("Affichage de l'erreur impossible !")
+                    self.erreur("Chargement incomplet de la feuille.")
                 finally:
                     for action in self._actions:
                         action()
@@ -1435,7 +1440,7 @@ class Feuille(object):
             if isinstance(arg, Objet):
                 for heritier in heritiers:
                     if arg is heritier:
-                        self.erreur(u"Définition circulaire dans %s : \
+                        self.erreur("Définition circulaire dans %s : \
                                    l'objet %s se retrouve dépendre de lui-même."
                                    %(valeur, nom))
                         #raise RuntimeError, "Definition circulaire dans %s : l'objet %s se retrouve dependre de lui-meme." %(valeur, nom)
@@ -1475,22 +1480,22 @@ class Feuille(object):
                 i += 1
         else:
             self.historique.restaurer(backup)
-            self.erreur(u"Erreur lors de la redéfinition de %s." %nom)
+            self.erreur("Erreur lors de la redéfinition de %s." %nom)
 
 
     def inventaire(self):
         objets = self.liste_objets(True)
         if param.debug:
             for obj in objets:
-                print "- " + obj.nom + " : " + repr(obj) + " (" + obj.type() + ")"
-        liste = [u"%s (%s%s)" % (uu(obj.nom_complet), uu(obj.titre(point_final=False)),
-                 ('' if obj.style("visible") else u" invisible")) for obj in objets
+                print("- " + obj.nom + " : " + repr(obj) + " (" + obj.type() + ")")
+        liste = ["%s (%s%s)" % (obj.nom_complet, obj.titre(point_final=False),
+                 ('' if obj.style("visible") else " invisible")) for obj in objets
                  if not isinstance(obj, (Variable_affichage, Pixel_unite))]
         liste.sort()
         return liste
 
     def nettoyer(self):
-        u"""Supprime les objets cachés inutiles.
+        """Supprime les objets cachés inutiles.
 
         Un objet caché est inutile si aucun objet visible ne dépend de lui.
         Les textes vides sont également supprimés."""
@@ -1503,13 +1508,13 @@ class Feuille(object):
                     obj.supprimer()
 
     def effacer_codage(self):
-        u"Efface tous les codages sur les segments, angles et arcs de cercles."
+        "Efface tous les codages sur les segments, angles et arcs de cercles."
         for obj in self.liste_objets(True):
             if obj.style("codage") is not None:
                 obj.style(codage = "")
 
     def coder(self):
-        u"Codage automatique de la figure (longueurs égales, angles égaux, et angles droits)."
+        "Codage automatique de la figure (longueurs égales, angles égaux, et angles droits)."
         def test(groupe, liste, i):
             if len(groupe) is 1:
                 groupe[0]["objet"].style(codage = "")
@@ -1520,8 +1525,8 @@ class Feuille(object):
                         elt["objet"].style(codage = liste[i])
                     return True
                 except IndexError:
-                    self.message(u"Le nombre de codages disponibles est insuffisant.")
-                    print_error(u"Le nombre de codages disponibles est insuffisant.")
+                    self.message("Le nombre de codages disponibles est insuffisant.")
+                    print_error("Le nombre de codages disponibles est insuffisant.")
 
         objets = self.objets.lister(False, type = (Segment, Arc_generique))
         lignes = [{"longueur": obj._longueur(), "objet": obj} for obj in objets]
@@ -1590,7 +1595,7 @@ class Feuille(object):
         Teste rapidement si l'objet est répertorié dans la feuille.
         (Ne cherche pas parmi les objets temporaires.)"""
 
-        return is_in(objet, self.objets.values())
+        return is_in(objet, list(self.objets.values()))
 
 
     def contient_objet_temporaire(self, objet):
@@ -1611,15 +1616,15 @@ class Feuille(object):
         return self.__point_temporaire__
 
     def start(self):
-        u"Autorise le lancement d'animations."
+        "Autorise le lancement d'animations."
         self._stop = False
 
     def stop(self):
-        u"Arrête toutes les animations en cours."
+        "Arrête toutes les animations en cours."
         self._stop = True
 
     def animer(self, nom, debut = 0, fin = 1, pas = 0.02, periode = 0.03):
-        u"""Anime la variable nommée `nom`.
+        """Anime la variable nommée `nom`.
 
         :param nom: nom de la variable dont on souhaite faire varier la valeur.
         :param debut: valeur initiale de la variable.
@@ -1647,11 +1652,11 @@ class Feuille(object):
                 self.log.append(messg)
 
 
-    def erreur(self, message, erreur = None):
-        self.message(u"Erreur : " + uu(message))
+    def erreur(self, message, erreur=None):
+        self.message("Erreur : " + message)
         if erreur is None:
             erreur = RuntimeError
-        raise erreur, str3(message)
+        raise erreur(message)
 
 
     def save_log(self, log):
@@ -1668,7 +1673,7 @@ class Feuille(object):
 
 
     def lister_figures(self):
-        u"""Renvoie deux listes de figures (artistes matplotlib).
+        """Renvoie deux listes de figures (artistes matplotlib).
 
         La seconde est celle des figures qui vont bouger avec l'objet deplacé ;
         et la première, des autres qui vont rester immobiles.
@@ -1711,13 +1716,13 @@ class Feuille(object):
 
 
     def effacer_traces(self):
-        u"Efface toutes les traces (sans enlever le mode trace des objets)."
+        "Efface toutes les traces (sans enlever le mode trace des objets)."
         for objet in self.liste_objets():
             objet.effacer_trace()
         self.affichage_perime()
 
-    def objets_en_gras(self, *objets):
-        u"""Met en gras les objets indiqués, et remet les autres objets en état "normal" le cas échéant."""
+    def met_objets_en_gras(self, *objets):
+        """Met en gras les objets indiqués, et remet les autres objets en état "normal" le cas échéant."""
 
         changements = False
         for objet in self.liste_objets(True):
@@ -1754,25 +1759,25 @@ class Feuille(object):
 
 
     def nom_aleatoire(self, objet, prefixe=None):
-        u"""Génère un nom d'objet non encore utilisé.
+        """Génère un nom d'objet non encore utilisé.
 
         Si possible, le nom sera de la forme 'prefixe' + chiffres.
         Sinon, un préfixe aléatoire est généré."""
         prefixe = (prefixe if prefixe else objet._prefixe_nom)
         existants = self.objets.noms
-        for i in xrange(1000):
+        for i in range(1000):
             n = len(prefixe)
             numeros = [int(s[n:]) for s in existants if re.match(prefixe + "[0-9]+$", s)]
             nom = prefixe + (str(max(numeros) + 1) if numeros else '1')
             nom = self.objets._Dictionnaire_objets__verifier_syntaxe_nom(objet, nom, skip_err=True)
             if nom is not None:
                 return nom
-            prefixe = ''.join(choice(letters) for i in xrange(8))
-        raise RuntimeError, "Impossible de trouver un nom convenable apres 1000 essais !"
+            prefixe = ''.join(choice(ascii_letters) for i in range(8))
+        raise RuntimeError("Impossible de trouver un nom convenable apres 1000 essais !")
 
 
 
     def pause(self):
         Objet.souffler()
         if self._stop:
-            raise RuntimeError, "Interruption de la macro."
+            raise RuntimeError("Interruption de la macro.")
