@@ -1,6 +1,4 @@
-#!/usr/bin/env python
 # -*- coding: iso-8859-1 -*-
-from __future__ import division # 1/2 == .5 (par defaut, 1/2 == 0)
 
 ##--------------------------------------#######
 #           Mathlib 2 (sympy powered)         #
