@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import division # 1/2 == .5 (par defaut, 1/2 == 0)
 
 ##--------------------------------------#######
 #                Intervalles                  #
@@ -30,15 +29,15 @@ from sympy import oo, sympify, S, Symbol
 from sympy.core.sympify import SympifyError
 import sympy
 
-from ..pylib import print_error, str2
+from ..pylib import print_error
 from .. import param
 from .parsers import _convertir_latex_frac
-from .printers import custom_str as str
+from .printers import custom_str as str_
 
 
 class Ensemble(object):
     def __new__(cls, *args, **kw):
-        if len(args) == 1 and isinstance(args[0], basestring):
+        if len(args) == 1 and isinstance(args[0], str):
             return conversion_chaine_ensemble(args[0], utiliser_sympy = True)
         instance = object.__new__(cls)
         instance._initialiser(*args, **kw)
@@ -46,7 +45,7 @@ class Ensemble(object):
 
 
 class Union(Ensemble):
-    u"""Une union finie d'intervalles réels. Les valeurs numériques isolées sont converties en singletons.
+    """Une union finie d'intervalles réels. Les valeurs numériques isolées sont converties en singletons.
     Lors de l'initialisation, elle est reecrite sous forme d'union disjointe et ordonnée.
 
     Les opération sur les unions d'intervalles sont :
@@ -130,8 +129,9 @@ class Union(Ensemble):
         ##self.__radd__(y)
 
     def simplifier(self):
-        ints = [intervalle for intervalle in self.intervalles if not intervalle.vide]
-        ints.sort()
+        # On classe les intervalles par borne inférieure (puis supérieure si besoin pour départager).
+        ints = sorted((intervalle for intervalle in self.intervalles if not intervalle.vide),
+               key=(lambda i: (i.inf, i.sup)))
         #print ints
         #print self.intervalles
         for i in range(len(ints) - 1):
@@ -160,16 +160,16 @@ class Union(Ensemble):
     def __str__(self):
         if self.vide:
             return '{}'
-        return "U".join(str(intervalle) for intervalle in self.intervalles).replace("}U{", " ; ")
+        return "U".join(str_(intervalle) for intervalle in self.intervalles).replace("}U{", " ; ")
 
     def __repr__(self):
-        return "Ensemble(%s)" %repr(str(self))
+        return "Ensemble(%s)" %repr(str_(self))
 
-    def __nonzero__(self):
+    def __bool__(self):
         return not self.vide
 
     def __neg__(self):
-        u"complémentaire"
+        "complémentaire"
         return reduce(lambda x, y: x*y, [-intervalle for intervalle in self.intervalles], Intervalle())
 
     def __pos__(self):
@@ -207,7 +207,7 @@ class Union(Ensemble):
 
 
     def extremites(self, _min, _max):
-        u"""Retourne les extrémités de chaque intervalle.
+        """Retourne les extrémités de chaque intervalle.
 
         Chaque extrémité est donnée sous la forme de couples (_float, _str),
         où _str peut prendre les valeurs ".", ")", "(" ou "o".
@@ -231,12 +231,12 @@ class Union(Ensemble):
 
     @property
     def adherence(self):
-        u"L'adhérence de l'ensemble (ie. le plus petit ensemble fermé qui le contienne)."
+        "L'adhérence de l'ensemble (ie. le plus petit ensemble fermé qui le contienne)."
         return Union(Intervalle(intervalle.inf, intervalle.sup, True, True)
                                 for intervalle in self.intervalles)
 
     def asarray(self, _min, _max, pas):
-        u"""Génère une liste d'objets 'array', correspondant à chaque intervalle.
+        """Génère une liste d'objets 'array', correspondant à chaque intervalle.
 
         On se limite à des valeurs comprises entre '_min' et '_max', avec le pas 'pas'."""
         arrays = []
@@ -254,7 +254,7 @@ class Union(Ensemble):
 
 
     def evalf(self, n = 15, round_=None, **options):
-        u"Convertit les bornes de chaque intervalle en float."
+        "Convertit les bornes de chaque intervalle en float."
         union = vide
         def evalf(nbr):
             if nbr in (-oo, +oo):
@@ -280,7 +280,7 @@ class Union(Ensemble):
 
 
 class Intervalle(Union):
-    u"""Un intervalle réel non vide.
+    """Un intervalle réel non vide.
     Les opération sur les intervalles sont :
     - l'union : symbole "A+B"
     - l'intersection : symbole "A*B"
@@ -320,14 +320,19 @@ class Intervalle(Union):
             return [self]
 
 
-    def __cmp__(self, y):
-        c = cmp(float(self.inf), float(y.inf))
-        if c:   return c
-        else:   return cmp(float(self.sup), float(y.sup))
+    #~ def __gt__(self, y):
+        #~ if not isinstance(y, Intervalle):
+            #~ raise TypeError("Impossible de comparer un Intervalle avec un objet de type %s." % type(y))
+        #~ if self.inf != y.inf:
+            #~ return float(self.inf) > float(y.inf)
+        #~ else:
+            #~ return float(self.sup) > float(y.sup)
 
+    #~ def __ge__(self, y):
+        #~ return self > y or float(self.inf) == float(y.inf)
 
     def __mul__(self, y):
-        u"intersection"
+        "intersection"
         if not isinstance(y, Union):
             y = Union(y)
 
@@ -375,16 +380,11 @@ class Intervalle(Union):
 
     def __str__(self):
         if self.vide:
-            return "{}"
+            return "\u00D8" # "Ø" ; u"\u2205" ne fonctionne pas sous Windows XP
         elif self.inf == self.sup:
-            return "{%s}" %str(self.inf)
-        return (self.inf_inclus and "[" or "]") + str(self.inf) + ";" + str(self.sup) + (self.sup_inclus and "]" or "[")
+            return "{%s}" %str_(self.inf)
+        return (self.inf_inclus and "[" or "]") + str_(self.inf) + ";" + str_(self.sup) + (self.sup_inclus and "]" or "[")
 
-    def __unicode__(self):
-        if self.vide:
-            return u"\u00D8" # "Ø" ; u"\u2205" ne fonctionne pas sous Windows XP
-        else:
-            return unicode(str(self))
 
     def __copy__(self):
         return Intervalle(self.inf, self.sup, self._inf_inclus, self._sup_inclus)
@@ -403,7 +403,7 @@ class Intervalle(Union):
 
 
 def _remplacer_virgule(chaine):
-    u"""Remplacement intelligent de la virgule par un point ou un point-virgule.
+    """Remplacement intelligent de la virgule par un point ou un point-virgule.
 
     Dans la mesure du possible, essaie de deviner si la virgule est utilisée
     comme séparateur décimal, ou entre deux valeurs.
@@ -413,17 +413,17 @@ def _remplacer_virgule(chaine):
         return chaine
     elif ';' in chaine and '.' not in chaine:
         if param.debug:
-            print(u"Warning (autocorrection): '" + chaine + "'\n"
+            print("Warning (autocorrection): '" + chaine + "'\n"
                 "Utilisation incorrecte d'une virgule.\n"
-                u"Utilisez le point comme séparateur décimal, ou modifiez les options.\n"
-                u"Enfin, ne mélangez pas les virgules et les points virgules.")
+                "Utilisez le point comme séparateur décimal, ou modifiez les options.\n"
+                "Enfin, ne mélangez pas les virgules et les points virgules.")
         return chaine.replace(',', '.')
     else:
         return chaine.replace(',', ';')
 
 
 def preformatage_ensemble(chaine):
-    u"""Formatage léger (qui reste humainement lisible)."""
+    """Formatage léger (qui reste humainement lisible)."""
     chaine = chaine.replace(" ", "")
 
     # Traduction du LaTeX
@@ -456,7 +456,7 @@ def preformatage_ensemble(chaine):
 
 
 def preformatage_geolib_ensemble(chaine):
-    u"""Cette fonction est destinée à un usage très spécifique dans geolib.
+    """Cette fonction est destinée à un usage très spécifique dans geolib.
 
     Elle accepte une syntaxe beaucoup plus souple que la précédente,
     et indique si les extrémités des intervalles doivent être affichés ou non.
@@ -512,7 +512,7 @@ def preformatage_geolib_ensemble(chaine):
 
 
 def formatage_ensemble(chaine, preformatage = True, utiliser_sympy = False):
-    u"""Les symboles à utiliser sont 'U' pour l'union, '^' pour l'intersection,
+    """Les symboles à utiliser sont 'U' pour l'union, '^' pour l'intersection,
     '-' ou '\\' pour la soustraction.
     R, R+, R*+, R-, R*- sont aussi acceptés."""
 
@@ -548,7 +548,7 @@ def conversion_chaine_ensemble(chaine, utiliser_sympy = False):
         else:
             return Symbol(nom)
     # À faire en dernier (remplace sympy.Union par intervalles.Union).
-    dico.update({"__builtins__": None,
+    dico.update({"__builtins__": {},
             "Intervalle": Intervalle,
             "Union": Union,
             "oo": oo,
@@ -557,13 +557,11 @@ def conversion_chaine_ensemble(chaine, utiliser_sympy = False):
             "Symbol": mySymbol,
             })
 
-    chaine = str2(chaine)
     if utiliser_sympy:
         try:
-            #print str2(chaine), dico
             return sympify(chaine, dico)
         except (SympifyError, TypeError) as e:
-            print "Warning: %s in %s." %(e, str2(chaine))
+            print("Warning: %s in %s." %(e, chaine))
             print_error()
     return eval(chaine, dico, dico)
 
