@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
-from __future__ import division # 1/2 == .5 (par defaut, 1/2 == 0)
 
 from wxgeometrie.mathlib.custom_objects import Decim
-from sympy import Symbol, Rational
+from sympy import Symbol, Rational, S
 
 from tools.testlib import assertEqual
 
@@ -10,5 +9,9 @@ x = Symbol('x')
 
 
 def test_Decim():
+    expr = S.One*Decim('0.3')
+    assert isinstance(expr,  Decim), type(expr)
+    expr = Decim('0.3')*x
+    assert isinstance(expr.args[0],  Decim), type(expr.args[0])
     assertEqual(repr(Decim(1, 2)*x + Decim(1, 5)), '0.5*x + 0.2')
-    assertEqual(repr(Decim(1, 2)*Rational(1, 5)), '0.1')
\ No newline at end of file
+    assertEqual(repr(Decim(1, 2)*Rational(1, 5)), '0.1')
