@@ -1,6 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import division # 1/2 == .5 (par defaut, 1/2 == 0)
-from __future__ import with_statement
 
 #    .----------------------------------------.
 #    |    Exercices : Équations de droites    |
@@ -28,8 +26,9 @@ from random import randint, choice
 from itertools import chain
 from functools import partial
 
-from PyQt4.QtGui import (QVBoxLayout, QLabel, QPushButton, QHBoxLayout,
-                         QMessageBox, QTextEdit, QColor, QToolTip, QCursor)
+from PyQt5.QtGui import  QColor, QCursor
+from PyQt5.QtWidgets import QVBoxLayout, QLabel, QPushButton, QHBoxLayout,\
+    QMessageBox, QTextEdit, QToolTip
 
 from sympy import S, solve, gcd, simplify
 from sympy.core.sympify import SympifyError
@@ -55,14 +54,14 @@ class EqMenuBar(ExerciceMenuBar):
 
 class ExercicesEquationsDroites(Exercice):
 
-    titre = u"Équations de droites" # Donner un titre a chaque module
+    titre = "Équations de droites" # Donner un titre a chaque module
 
     def __init__(self, *args, **kw):
         Exercice.__init__(self, BarreOutils = BarreOutilsExEqDte, *args, **kw)
 
 
     def reinitialiser(self):
-        u"""Paramètres par défaut."""
+        """Paramètres par défaut."""
         Exercice.reinitialiser(self)
         self.canvas.afficher_axes = True
         self.canvas.quadrillage_defaut()
@@ -75,7 +74,7 @@ class ExercicesEquationsDroites(Exercice):
     # ------------------------------------------------------
 
     def exercice_lire_equation_AB(self, pointA, pointB):
-        u"""Lire graphiquement l'équation de la droite (AB).
+        """Lire graphiquement l'équation de la droite (AB).
 
         C'est l'exercice à la base des niveaux 1 à 7.
         """
@@ -93,15 +92,15 @@ class ExercicesEquationsDroites(Exercice):
             reponse = 'x=' + str(xA)
         else:
             reponse = ('y=%s*x+%s' % self.eq_reduite(pointA, pointB))
-        print('fen::', self.canvas.fenetre)
+        print(('fen::', self.canvas.fenetre))
         xmin, xmax, ymin, ymax = self.canvas.fenetre
-        print 'Fenetre::', self.canvas.fenetre, '--', xmin, ymin
+        print('Fenetre::', self.canvas.fenetre, '--', xmin, ymin)
         champ = Champ('', xmin, ymin, couleur_fond='#ffffb5',
-                    prefixe=(ur"Dans le repère $(O;\,\vec\imath,\,\vec\jmath)$, "
-                             u"la droite $(AB)$ a pour équation "),
+                    prefixe=(r"Dans le repère $(O;\,\vec\imath,\,\vec\jmath)$, "
+                             "la droite $(AB)$ a pour équation "),
                     alignement_horizontal='left', alignement_vertical='bottom',
                     attendu=reponse)
-        print 'xy::', champ.xy
+        print('xy::', champ.xy)
         champ.valider = self.valider_eq
         champ.evt_valider = self.compter_points
         self.feuille_actuelle.objets['champ1'] = champ
@@ -139,7 +138,7 @@ class ExercicesEquationsDroites(Exercice):
 
 
     def niveau4(self):
-        u"""Droite horizontale."""
+        """Droite horizontale."""
         yA = self.relatif(7)
         while True:
             xA = self.relatif(7)
@@ -150,7 +149,7 @@ class ExercicesEquationsDroites(Exercice):
 
 
     def niveau5(self):
-        u"""Droite verticale."""
+        """Droite verticale."""
         xA = self.relatif(7)
         while True:
             yA = self.relatif(7)
@@ -164,7 +163,7 @@ class ExercicesEquationsDroites(Exercice):
         """Droite oblique ne coupant pas l'axe des ordonnées sur une
         graduation ; il faut donc calculer (ou deviner) l'ordonnée
         à l'origine."""
-        for i in xrange(1000):
+        for i in range(1000):
             while True:
                 xA = self.relatif(n)
                 xB = self.relatif(n)
@@ -177,7 +176,7 @@ class ExercicesEquationsDroites(Exercice):
                     break
             # On calcule l'ordonnée à l'origine (sous forme de fraction sympy).
             a, b = self.eq_reduite((xA, yA), (xB, yB))
-            print b
+            print(b)
             if b.q not in (1, 2):
                 # Le dénominateur de l'ordonnée à l'origine ne doit pas être 1 ou 2.
                 break
@@ -189,7 +188,7 @@ class ExercicesEquationsDroites(Exercice):
         self.canvas.ratio = 4
         self.canvas.quadrillages = (((.25, 1), ':', 0.5, 'k'),)
         self.canvas.fenetre = -4.5, 4.5, -10, 8
-        print('fen::', self.canvas.fenetre)
+        print(('fen::', self.canvas.fenetre))
         xmin, xmax, ymin, ymax = self.canvas.fenetre
         self.feuille_actuelle.objets['champ1'].xy = xmin, ymin
 
@@ -216,7 +215,7 @@ class ExercicesEquationsDroites(Exercice):
 
 
     def eq_reduite(self, A, B):
-        u"""Équation réduite exacte de la droite (AB).
+        """Équation réduite exacte de la droite (AB).
 
         La droite ne doit pas être verticale."""
         xA, yA = A
@@ -232,7 +231,7 @@ class ExercicesEquationsDroites(Exercice):
     # --------------------------------------------
 
     def niveau8(self):
-        u"""Résolution graphique de système.
+        """Résolution graphique de système.
 
         Construire deux droites d'équations données.
         Lire les coordonnées du point d'intersection."""
@@ -262,7 +261,7 @@ class ExercicesEquationsDroites(Exercice):
             if all((A[0] - C[0], A[1] - C[1], B[0] - C[0], B[1] - C[1])):
                 break
         if param.debug:
-            print 'A,B,C:', A, B, C
+            print('A,B,C:', A, B, C)
         # on génère les deux équations de droite
         x = S('x')
         ##def eq_latex(pt1, pt2):
@@ -283,15 +282,15 @@ class ExercicesEquationsDroites(Exercice):
 
         xmin, xmax, ymin, ymax = self.canvas.fenetre
 
-        txt = Texte((u"On note $d_1$ la droite d'équation %s, "
-                  u"et $d_2$ la droite d'équation %s.\n"
-                  u"Construire les droites $d_1$ puis $d_2$ dans le repère ci-dessous.")
+        txt = Texte(("On note $d_1$ la droite d'équation %s, "
+                  "et $d_2$ la droite d'équation %s.\n"
+                  "Construire les droites $d_1$ puis $d_2$ dans le repère ci-dessous.")
                   % (eq1, eq2), "xmin", "ymax", couleur_fond='#ffffb5', fixe=True,
                   alignement_horizontal='left', alignement_vertical='top')
         self.feuille_actuelle.objets['txt1'] = txt
         systeme = r'$\left\{\stackrel{%s}{%s}\right.$' % (eq1.strip('$'), eq2.strip('$'))
         champ = Champ('', "xmin", "ymin",
-                 prefixe=(u"Le couple solution du système %s est (" % systeme),
+                 prefixe=("Le couple solution du système %s est (" % systeme),
                  alignement_vertical='bottom', alignement_horizontal='left',
                  attendu=str(C), couleur_fond='#ffffb5', suffixe=')')
         self.feuille_actuelle.objets['champ1'] = champ
@@ -307,7 +306,7 @@ class ExercicesEquationsDroites(Exercice):
 
 
     def verifier_feuille(self, eq1, eq2):
-        print eq1, eq2
+        print(eq1, eq2)
         for nom, eq in (('d1', eq1), ('d2', eq2)):
             if nom in self.feuille_actuelle.objets.noms:
                 d = self.feuille_actuelle.objets[nom]
@@ -323,7 +322,7 @@ class ExercicesEquationsDroites(Exercice):
                     if nom == 'd1':
                         msg += ' Construisez maintenant d2.'
                 else:
-                    print self.eq_reduite(*d), eq
+                    print(self.eq_reduite(*d), eq)
                     d.style(couleur='r')
                     # On peut mettre n'importe quoi différent de ok dans
                     # champ, l'idée étant que si la droite est fausse mais
@@ -347,7 +346,7 @@ class ExercicesEquationsDroites(Exercice):
 
 
     def ax_b(self):
-        u"Générer une expression sympy de la forme ax+b, avec a, b dans Z."
+        "Générer une expression sympy de la forme ax+b, avec a, b dans Z."
         return self.relatif()*S('x') + self.relatif()
 
 
