@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-from __future__ import division # 1/2 == .5 (par defaut, 1/2 == 0)
 
 ##########################################################################
 #
@@ -39,7 +38,7 @@ from sympy import sympify
 
 
 def is_in(element, _list):
-    u"""Teste si l'élement est dans la liste, en effectuant un test d'identité (is) et non d'égalité (==)."""
+    """Teste si l'élement est dans la liste, en effectuant un test d'identité (is) et non d'égalité (==)."""
     for elt in _list:
         if elt is element:
             return True
@@ -56,13 +55,13 @@ def is_in(element, _list):
 ##    return any(elt is element for elt in _list)
 
 def mreplace(main_string, list_of_strings, new_string = ""):
-    u"""Remplace, dans "main_string", toutes les sous-chaines de "list_of_strings", par la chaine "new_string"."""
+    """Remplace, dans "main_string", toutes les sous-chaines de "list_of_strings", par la chaine "new_string"."""
     for old_string in list_of_strings:
         main_string = main_string.replace(old_string, new_string)
     return main_string
 
 def recursive_replace(main_string, old_string, new_string = "", max_loops = 10000, max_len = 1000000):
-    u"""Remplace, dans "main_string", la sous-chaîne "old_string" par "new_string", au besoin en plusieurs passes.
+    """Remplace, dans "main_string", la sous-chaîne "old_string" par "new_string", au besoin en plusieurs passes.
 
     En fin de processus, la sous-chaîne old_string ne subsiste plus dans la chaîne.
     Renvoie une erreur si le processus ne semble pas converger.
@@ -87,14 +86,14 @@ def recursive_replace(main_string, old_string, new_string = "", max_loops = 1000
         chaine = main_string
         main_string = main_string.replace(old_string, new_string)
         if loops > max_loops:
-            raise RuntimeError, "Nombre de passes superieur au maximum autorise."
+            raise RuntimeError("Nombre de passes superieur au maximum autorise.")
         if len(main_string) > max_len:
-            raise OverflowError, "Taille de la chaine superieure au maximum autorise."
+            raise OverflowError("Taille de la chaine superieure au maximum autorise.")
     return main_string
 
 
 def recursive_mreplace(main_string, list_of_strings, new_string = "", max_loops = 10000, max_len = 1000000):
-    u"""Remplace, dans "main_string", toutes les sous-chaines de "list_of_strings" par "new_string", au besoin en plusieurs passes.
+    """Remplace, dans "main_string", toutes les sous-chaines de "list_of_strings" par "new_string", au besoin en plusieurs passes.
 
     En fin de processus, la sous-chaîne old_string ne subsiste plus dans la chaîne.
     Renvoie une erreur si le processus ne semble pas converger.
@@ -121,9 +120,9 @@ def recursive_mreplace(main_string, list_of_strings, new_string = "", max_loops
         chaine = main_string
         main_string = mreplace(main_string, list_of_strings, new_string)
         if loops > max_loops:
-            raise RuntimeError, "Nombre de passes superieur au maximum autorise."
+            raise RuntimeError("Nombre de passes superieur au maximum autorise.")
         if len(main_string) > max_len:
-            raise OverflowError, "Taille de la chaine superieure au maximum autorise."
+            raise OverflowError("Taille de la chaine superieure au maximum autorise.")
     return main_string
 
 
@@ -140,13 +139,13 @@ def mfind(chaine, car):
 
 
 def msplit(main_string, list_of_separators):
-    u"""Découpe la chaine "main_string", selon les séparateurs définis dans "list_of_separators"."""
+    """Découpe la chaine "main_string", selon les séparateurs définis dans "list_of_separators"."""
     return mreplace(main_string, list_of_separators[1:], list_of_separators[0]).split(list_of_separators[0])
 
 
 
 def removeend(main_string, *substrings):
-    u"Enlève les éventuelles occurences de substring en fin de chaine."
+    "Enlève les éventuelles occurences de substring en fin de chaine."
     if substrings and True not in (sub == "" for sub in substrings): # pour éviter une éventuelle boucle infinie.
         test = True
         while test:
@@ -162,7 +161,7 @@ def removeend(main_string, *substrings):
 
 
 def removestart(main_string, *substrings):
-    u"Enlève les éventuelles occurences de substring en début de chaine."
+    "Enlève les éventuelles occurences de substring en début de chaine."
     if substrings and True not in (sub == "" for sub in substrings): # pour éviter une éventuelle boucle infinie.
         test = True
         while test:
@@ -178,12 +177,12 @@ def removestart(main_string, *substrings):
 
 
 def no_twin(liste):
-    u"""Elimine les doublons dans une liste.
+    """Elimine les doublons dans une liste.
     Si tous les élements de la liste sont 'hashables', mieux vaut utiliser la fonction set."""
     dico = {}
     for elt in liste:
         dico[id(elt)] = elt
-    return dico.values()
+    return list(dico.values())
 
 #def ntwin(l): return dict((id(elt), elt) for elt in l).values() # plus élégant, mais 50% plus lent ?!?
 
@@ -191,7 +190,7 @@ def no_twin(liste):
 
 
 def advanced_split(main_string, separator, keep_empty_str = False, symbols = "([{}])"):
-    u"""Découpe la chaine "main_string" de manière intelligente,
+    """Découpe la chaine "main_string" de manière intelligente,
     en ignorant les séparateurs compris dans un groupe entre parenthèses, crochets, accolades, guillemets.
     Attention, separateur ne peut donc pas être une parenthèse, un crochet, une accolade ou un guillemet !
     Par défaut, supprime également les chaines vides."""
@@ -201,7 +200,7 @@ def advanced_split(main_string, separator, keep_empty_str = False, symbols = "([
     crochets = 0 # idem pour les crochets
     accolades = 0 # idem
     coupures = [-1] # endroits ou il faudra couper la chaine
-    for i in xrange(len(main_string)):
+    for i in range(len(main_string)):
         a = main_string[i]
         if a in ("'", '"'):
             if in_string:
@@ -232,7 +231,7 @@ def advanced_split(main_string, separator, keep_empty_str = False, symbols = "([
 
 
 def regsub(regular_exp, main_string, action = ""):
-    u"""Transforme la chaine "main_string" :
+    """Transforme la chaine "main_string" :
     Il applique aux parties vérifiant "regular_exp" le traitement "action".
 
     >>> from wxgeometrie.pylib.fonctions import regsub
@@ -241,14 +240,16 @@ def regsub(regular_exp, main_string, action = ""):
     >>> regsub("[a-z]+", "hello world !", lambda s: s[1:])
     'ello orld !'
     """
-    if isinstance(action, basestring):
+    if isinstance(action, str):
         return re.sub(regular_exp, action, main_string)
     else:
         return re.sub(regular_exp, lambda x: action(x.group(0)), main_string)
 
 
+
+
 class WeakList(weakref.WeakValueDictionary):
-    u"""Une 'liste' de réferences faibles.
+    """Une 'liste' de réferences faibles.
 
     Le terme 'liste' est trompeur, la syntaxe des listes de python n'est pas implémentée,
     exceptée les méthodes append(), et remove(), et la conversion en liste.
@@ -266,10 +267,10 @@ class WeakList(weakref.WeakValueDictionary):
 
     def append(self, valeur):
         u"Ajoute une valeur en fin de liste."
-        self[max(self.keys() or [0]) + 1] = valeur
+        self[max(self.keys(), default=0) + 1] = valeur
 
     def remove(self, valeur):
-        u"""Supprime la valeur de la liste.
+        """Supprime la valeur de la liste.
 
         Un test d'identité (et non d'égalité) est effectué ('is' et non '==').
         Si la valeur est présente plusieurs fois, elle n'est supprimée qu'une seule fois.
@@ -279,10 +280,10 @@ class WeakList(weakref.WeakValueDictionary):
             if value is valeur:
                 del self[key] # il faut qu'il s'agisse du même objet
                 return
-        raise ValueError,  repr(valeur) + " is not in WeakList"
+        raise ValueError(repr(valeur) + " is not in WeakList")
 
     def compare_and_remove(self, valeur):
-        u"""Supprime la valeur de la liste.
+        """Supprime la valeur de la liste.
 
         Un test d'égalité est effectué ('==' et non 'is').
         Si la valeur est présente plusieurs fois, elle n'est supprimée qu'une seule fois.
@@ -292,10 +293,10 @@ class WeakList(weakref.WeakValueDictionary):
             if value == valeur:
                 del self[key] # un objet égal suffit
                 return
-        raise ValueError,  repr(valeur) + " not in WeakList"
+        raise ValueError(repr(valeur) + " not in WeakList")
 
     def remove_all(self, valeur):
-        u"""Supprime la valeur de la liste.
+        """Supprime la valeur de la liste.
 
         Un test d'identité (et non d'égalité) est effectué ('is' et non '==').
         Toutes les occurences de la valeur sont supprimées.
@@ -304,7 +305,7 @@ class WeakList(weakref.WeakValueDictionary):
             if value is valeur: del self[key] # il faut qu'il s'agisse du même objet
 
     def compare_and_remove_all(self, valeur):
-        u"""Supprime la valeur de la liste.
+        """Supprime la valeur de la liste.
 
         Un test d'égalité est effectué ('==' et non 'is').
         Toutes les occurences de la valeur sont supprimées.
@@ -313,16 +314,46 @@ class WeakList(weakref.WeakValueDictionary):
             if value == valeur: del self[key] # un objet égal suffit
 
     def __str__(self):
-        return str(self.values()) + " (WeakList)"
+        return str(list(self.values())) + " (WeakList)"
 
     def __iter__(self):
-        return self.itervalues()
+        return iter(self.values())
 
     def __getitem__(self, n):
-        return self.values()[n]
+        return list(self.values())[n]
 
     def __contains__(self, item):
-        return item in self.itervalues()
+        return item in self.values()
+
+
+class WeakMultiSet(weakref.WeakKeyDictionary):
+    """A WeakValueDictionary which keeps count of how many times an object was added.
+
+    The interface implements only the methods remove() and add()
+    to emulate a set.
+
+    When an element is removed, the count is actually decrease.
+    If count reaches 0, the element is discarded (key is removed).
+
+    Additionnaly, method remove_completely() discard the element
+    whatever the count.
+
+    This is quite similar to collect.Counter, except that entries are deleted
+    when count reaches 0, and weak refrences are used."""
+    def remove(self, elt):
+        self[elt] -= 1
+        if self[elt] == 0:
+            del self[elt]
+
+    def add(self, elt):
+        if elt in self:
+            self[elt] += 1
+        else:
+            self[elt] = 1
+
+    def remove_completely(self, elt):
+        del self[elt]
+
 
 
 def extract_error(chaine=''):
@@ -334,24 +365,24 @@ def extract_error(chaine=''):
     lignes.append('Traceback (most recent call last)')
     for fichier, ligne, fonction, code in tb:
         lignes.append('    File "%s", line %s, in %s'
-                % (uu(fichier), str(ligne), uu(fonction)))
+                % (str(fichier), str(ligne), str(fonction)))
         if code is not None:
-            lignes.append('        ' + uu(code))
-    lignes.append(uu(typ.__name__) + ": " + uu(val))
+            lignes.append('        ' + str(code))
+    lignes.append(typ.__name__ + ": " + str(val))
     lignes.append("Warning: this error was not raised.")
     return '\n'.join(lignes)
 
 
 
 def print_error(chaine=''):
-    u"""Affiche l'erreur sans interrompre le programme.
+    """Affiche l'erreur sans interrompre le programme.
     C'est un alias de sys.excepthook, mais qui est plus souple avec les encodages.
     """
     print(extract_error(chaine))
 
 
 def rstrip_(s, end):
-    u"""Supprime récursivement 'end' de la fin de la chaîne 's'.
+    """Supprime récursivement 'end' de la fin de la chaîne 's'.
 
     >>> from wxgeometrie.pylib.fonctions import rstrip_
     >>> rstrip_('blabla_suffixe_fixe_suffixe_suffixe', '_suffixe')
@@ -376,7 +407,7 @@ def rstrip_(s, end):
 
 # http://stackoverflow.com/questions/2556108/rreplace-how-to-replace-the-last-occurence-of-an-expression-in-a-string
 def rreplace(s, old, new, count):
-    u"""rreplace (s, old, new, count) -> string
+    """rreplace (s, old, new, count) -> string
 
     Return a copy of string S with the first count occurrences of substring
     old replaced by new, starting from right to left."""
@@ -385,7 +416,7 @@ def rreplace(s, old, new, count):
 
 
 def split_geoname(name):
-    u"""Tente de décomposer un nom d'objet géométrique en plusieurs noms.
+    """Tente de décomposer un nom d'objet géométrique en plusieurs noms.
 
     Ex:
     1) "AB" -> ("A","B")
@@ -399,7 +430,7 @@ def split_geoname(name):
 
 
 def convert_geoname(name, level = 0):
-    u"""Convertit le nom entré par l'utilisateur en un nom réellement interprétable.
+    """Convertit le nom entré par l'utilisateur en un nom réellement interprétable.
 
     Une conversion de niveau 1 est appliquée dans les boîtes de dialogue.
 
@@ -421,7 +452,7 @@ def convert_geoname(name, level = 0):
 
 
 def split_around_parenthesis(main_string, position = 0, leftbracket = "("):
-    u"""Coupe le premier groupe entre parentheses rencontré, en tenant compte des guillemets.
+    """Coupe le premier groupe entre parentheses rencontré, en tenant compte des guillemets.
 
     'leftbracket' peut prendre les valeurs "(", "[" ou "{"
     La parenthese ouvrante du groupe sera la première trouvée à droite de 'position'
@@ -436,7 +467,7 @@ def split_around_parenthesis(main_string, position = 0, leftbracket = "("):
     rightbracket = {"(": ")", "[": "]", "{": "}"}[leftbracket]
     prefixe = main_string[:position]
     chaine = main_string[position + 1:]
-    for i in xrange(len(chaine)):
+    for i in range(len(chaine)):
         a = chaine[i]
         if a in ("'", '"'):
             if in_string:
@@ -506,7 +537,7 @@ def find_closing_bracket(expr, start = 0, brackets = '{}'):
     else:
         return start + index - 1 # last caracter is the searched bracket :-)
 
-    raise ValueError, 'unbalanced brackets (%s) while scanning %s...' %(balance, repr(expr_deb))
+    raise ValueError('unbalanced brackets (%s) while scanning %s...' %(balance, repr(expr_deb)))
 
 
 def warning(message, type_warning = Warning, level=0):
@@ -516,103 +547,23 @@ def warning(message, type_warning = Warning, level=0):
 def deprecation(message, level=0):
     warnings.warn(message, DeprecationWarning, stacklevel = (level + 3))
 
-#def unicode2(string_or_unicode, encodage = None):
-#    u"Convertit en unicode si besoin est, avec l'encodage de 'param.encodage' par défaut."
-#    if isinstance(string_or_unicode, str):
-#        try:
-#            return unicode(string_or_unicode, encodage or param.encodage)
-#        except UnicodeDecodeError:
-##            try:
-##                print "chaine :\n", string_or_unicode
-##                print unicode(string_or_unicode, "cp1252")
-##            except Exception:
-##                pass
-#            raise
-#    elif isinstance(string_or_unicode, unicode):
-#        return string_or_unicode
-#    else:
-#        try:
-#            return unicode(string_or_unicode)
-#        except UnicodeDecodeError:
-#            print type(string_or_unicode)
-#            raise
 
 
 
-def str2(string_or_unicode, encodage = None):
-    u"Convertit en string si besoin est, avec l'encodage de 'param.encodage' par défaut."
-    if isinstance(string_or_unicode, str):
-        return string_or_unicode
-    elif isinstance(string_or_unicode, unicode):
-        return string_or_unicode.encode(encodage or param.encodage)
-    else:
-        return str(string_or_unicode)
-
-def str3(unicode):
-    dict = {
-                'a': (u'à', u'â', u'ä', ),
-                'e': (u'é', u'è', u'ê', u'ë', ),
-                'i': (u'î', u'ï', ),
-                'o': (u'ô', u'ö', ),
-                'u': (u'ù', u'û', u'ü',  ),
-                'c': (u'ç', ),
-                'A': (u'À', u'Â', u'Ä', ),
-                'E': (u'É', u'È', u'Ê', u'Ë', ),
-                'I': (u'Î', u'Ï', ),
-                'O': (u'Ô', u'Ö', ),
-                'U': (u'Ù', u'Û', u'Ü',  ),
-                'C': (u'Ç', ),
-                }
-    for key, liste in dict.items():
-        for item in liste:
-            unicode = unicode.replace(item, key)
-    return str(unicode)
-
-
-
-def universal_unicode(chaine):
-    u"""Convertit en unicode, sans renvoyer d'erreur.
-
-    Tente de détecter l'encodage, en essayant successivement :
-        * la valeur de `param.encodage`
-        * utf-8
-        * latin-1
-
-    Si des erreurs persistent, les caractères intraduisibles sont remplacés
-    par des `?`.
-    """
-    if not isinstance(chaine, basestring):
-        try:
-            chaine = unicode(chaine)
-        except UnicodeError:
-            chaine = str(chaine)
-    if not isinstance(chaine, unicode):
-        try:
-            chaine = chaine.decode(param.encodage)
-        except UnicodeError:
-            try:
-                chaine = chaine.decode('utf8')
-            except UnicodeError:
-                chaine = chaine.decode('iso-8859-1', 'replace')
-    return chaine
-
-uu = universal_unicode
-
-
 
 def path2(chemin):
-    u"""Transforme le chemin en remplaçant les / et \\ selon le séparateur utilisé par le système.
+    """Transforme le chemin en remplaçant les / et \\ selon le séparateur utilisé par le système.
 
     % est remplacé par l'emplacement du programme (contenu dans param.EMPLACEMENT).
     Exemple : path2("%/wxgeometrie/images/archives/old.png").
     ~ fait référence au répertoire personnel de l'utilisateur (ex: /home/SteveB/ sous Linux.
     """
-    return os.path.normpath(os.path.expanduser(uu(chemin).replace("%", uu(param.EMPLACEMENT))))
+    return os.path.normpath(os.path.expanduser(chemin.replace("%", param.EMPLACEMENT)))
 
 
 
-# L'idée de compiler en une fois pour toute les expressions regulières n'est pas avantageuse :
-# le temps gagné ainsi est perdu à rechercher les entrées dans le dictionnaire.
+# L'idée de compiler en une fois pour toute les expressions regulières n'est pas avantageuse,
+# car python le fait déjà automatiquement pour celles utilisées le plus souvent.
 
 #~ def regsub(regular_exp, main_string, action = ""):
     #~ u"""Transforme la chaine "main_string" :
@@ -648,84 +599,86 @@ def path2(chemin):
             #~ return value
 
 
-class WeakRef(weakref.ref):
-    u"""WeakRef surclasse weakref.ref en modifiant sa méthode '__eq__'.
+#~ class WeakRef(weakref.ref):
+    #~ """WeakRef surclasse weakref.ref en modifiant sa méthode '__eq__'.
 
-    a == b <=> type(a) == type(b) == WeakRef and a() is b().
-    Le but est de ne pas appeler les méthodes __eq__ des objets référencés."""
+    #~ a == b <=> type(a) == type(b) == WeakRef and a() is b().
+    #~ Le but est de ne pas appeler les méthodes __eq__ des objets référencés."""
 
-    def __eq__(self, y):
-        if not (isinstance(self, WeakRef) and isinstance(y, WeakRef)):
-            return False
-        if self() is None or y() is None:
-            return self is y
-        return  self() is y()
+    #~ def __eq__(self, y):
+        #~ if not isinstance(y, WeakRef):
+            #~ return False
+        #~ if self() is None or y() is None:
+            #~ return self is y
+        #~ return self() is y()
+
+    #~ def __hash__(self):
+        #~ return id(self())
+
+
+#~ class CustomWeakKeyDictionary(weakref.WeakKeyDictionary):
+    #~ """WeakKeyDictionary utilisant Weakref au lieu de weakref.ref.
+    #~ """
+
+    #~ def __delitem__(self, key):
+        #~ del self.data[WeakRef(key)]
+
+    #~ def __getitem__(self, key):
+        #~ return self.data[WeakRef(key)]
+
+    #~ def __repr__(self):
+        #~ return "<WeakKeyDictionary at %s>" % id(self)
+
+    #~ def __setitem__(self, key, value):
+        #~ self.data[WeakRef(key, self._remove)] = value
+
+    #~ def copy(self):
+        #~ new = CustomWeakKeyDictionary()
+        #~ for key, value in self.data.items():
+            #~ o = key()
+            #~ if o is not None:
+                #~ new[o] = value
+        #~ return new
+
+    #~ def get(self, key, default=None):
+        #~ return self.data.get(WeakRef(key),default)
+
+    #~ def has_key(self, key):
+        #~ try:
+            #~ wr = WeakRef(key)
+        #~ except TypeError:
+            #~ return 0
+        #~ return wr in self.data
+
+    #~ def __contains__(self, key):
+        #~ try:
+            #~ wr = WeakRef(key)
+        #~ except TypeError:
+            #~ return 0
+        #~ return wr in self.data
 
 
 
-class CustomWeakKeyDictionary(weakref.WeakKeyDictionary):
-    """WeakKeyDictionary utilisant Weakref au lieu de weakref.ref.
-    """
+    #~ def pop(self, key, *args):
+        #~ return self.data.pop(WeakRef(key), *args)
 
-    def __delitem__(self, key):
-        del self.data[WeakRef(key)]
+    #~ def setdefault(self, key, default=None):
+        #~ return self.data.setdefault(WeakRef(key, self._remove),default)
 
-    def __getitem__(self, key):
-        return self.data[WeakRef(key)]
-
-    def __repr__(self):
-        return "<WeakKeyDictionary at %s>" % id(self)
-
-    def __setitem__(self, key, value):
-        self.data[WeakRef(key, self._remove)] = value
-
-    def copy(self):
-        new = CustomWeakKeyDictionary()
-        for key, value in self.data.items():
-            o = key()
-            if o is not None:
-                new[o] = value
-        return new
-
-    def get(self, key, default=None):
-        return self.data.get(WeakRef(key),default)
-
-    def has_key(self, key):
-        try:
-            wr = WeakRef(key)
-        except TypeError:
-            return 0
-        return wr in self.data
-
-    def __contains__(self, key):
-        try:
-            wr = WeakRef(key)
-        except TypeError:
-            return 0
-        return wr in self.data
-
-
-
-    def pop(self, key, *args):
-        return self.data.pop(WeakRef(key), *args)
-
-    def setdefault(self, key, default=None):
-        return self.data.setdefault(WeakRef(key, self._remove),default)
-
-    def update(self, dict=None, **kwargs):
-        d = self.data
-        if dict is not None:
-            if not hasattr(dict, "items"):
-                dict = type({})(dict)
-            for key, value in dict.items():
-                d[WeakRef(key, self._remove)] = value
-        if len(kwargs):
-            self.update(kwargs)
+    #~ def update(self, dict=None, **kwargs):
+        #~ d = self.data
+        #~ if dict is not None:
+            #~ if not hasattr(dict, "items"):
+                #~ dict = type({})(dict)
+            #~ for key, value in dict.items():
+                #~ d[WeakRef(key, self._remove)] = value
+        #~ if len(kwargs):
+            #~ self.update(kwargs)
 
 
 
 def debug(*messages):
-    u"""Affiche un (ou plusieurs) message(s) si le déboguage est actif."""
+    """Affiche un (ou plusieurs) message(s) si le déboguage est actif."""
     if param.debug:
         for message in messages:
             print(message)
@@ -733,16 +686,16 @@ def debug(*messages):
 @decorator
 def trace(f, *args, **kw):
     if param.debug:
-        print "Calling %s with args %s, %s" % (f.func_name, args, kw)
+        print("Calling %s with args %s, %s" % (f.__name__, args, kw))
     return f(*args, **kw)
 
 @decorator
 def full_trace(f, *args, **kw):
     if param.debug:
-        print '** Debugging info **'
+        print('** Debugging info **')
         traceback.print_stack()
-        print "Calling %s with args %s, %s" % (f.func_name, args, kw)
-        print '-------------------\n'
+        print("Calling %s with args %s, %s" % (f.__name__, args, kw))
+        print('-------------------\n')
     return f(*args, **kw)
 
 
@@ -769,7 +722,7 @@ def deprecated(message = ''):
 
 
 def traceit(frame, event, arg):
-    u"""'Trace' (suit) une fonction python.
+    """'Trace' (suit) une fonction python.
 
         Usage:
         import sys
@@ -782,7 +735,7 @@ def traceit(frame, event, arg):
             filename = filename[:-1]
         name = frame.f_globals["__name__"]
         line = linecache.getline(filename, lineno)
-        print "%s:%s: %s" % (name, lineno, line.rstrip())
+        print("%s:%s: %s" % (name, lineno, line.rstrip()))
     return traceit
 
 
@@ -796,40 +749,42 @@ def tracer_(booleen = True):
 def property2(fonction):
     return property(fonction, fonction)
 
-# Permet de contourner un bug de exec() sous Python 2.5 lorsque with_statement est activé
-assert "with_statement" not in locals()
-assert "with_statement" not in globals()
-def exec_(s, globals, locals):
-    exec(s, globals, locals)
+
+def _archive(string):
+    return zlib.compress(string.encode('utf8'))
+
+def _extract(data):
+    return zlib.decompress(data).decode('utf8')
 
 
 class CompressedList(list):
     def append(self, s):
-        list.append(self, zlib.compress(s))
+        list.append(self, _archive(s))
 
     def __getitem__(self, i):
-        return zlib.decompress(list.__getitem__(self, i))
+        return _extract(list.__getitem__(self, i))
 
     def __setitem__(self, i, s):
-        list.__setitem__(self, i, zlib.compress(s))
+        list.__setitem__(self, i, _archive(s))
 
     def remove(self, s):
-        list.remove(self, zlib.compress(s))
+        list.remove(self, _archive(s))
 
     def count(self, s):
-        return list.count(self, zlib.compress(s))
+        return list.count(self, _archive(s))
 
     def extend(self, iterable):
-        list.extend(self, (zlib.compress(s) for s in iterable))
+        list.extend(self, (_archive(s) for s in iterable))
 
     def index(self, s):
-        list.index(self, zlib.compress(s))
+        list.index(self, _archive(s))
 
     def insert(self, i, s):
-        list.insert(self, i, zlib.compress(s))
+        list.insert(self, i, _archive(s))
 
     def pop(self, i = -1):
-        return zlib.decompress(list.pop(self, i))
+        return _extract(list.pop(self, i))
+
 
 def pstfunc(chaine):
     args = []
@@ -852,7 +807,7 @@ def pstfunc(chaine):
 
 
 class NoArgument(object):
-    u'''Utilisé comme valeur par défaut, pour savoir si un argument optionnel
+    '''Utilisé comme valeur par défaut, pour savoir si un argument optionnel
     a été passé. Une seule instance peut-être crée.'''
     __instance = None
 
@@ -885,7 +840,7 @@ class OrderedDict(dict):
         return iter(self.__keys)
 
     def __repr__(self):
-        return "MyOrderedDict(%s)"%repr(self.items())
+        return "MyOrderedDict(%s)"%repr(list(self.items()))
 
     def keys(self):
         return self.__keys[:]
@@ -897,7 +852,7 @@ class OrderedDict(dict):
         return [(key, self[key]) for key in self.__keys]
 
     def copy(self):
-        return self.__class__(self.iteritems())
+        return self.__class__(iter(self.items()))
 
     def iterkeys(self):
         return iter(self)
